changeset 101008:5aa3a4e05089

Replace last-command-char with last-command-event.
author Glenn Morris <rgm@gnu.org>
date Fri, 09 Jan 2009 04:29:16 +0000
parents 89a622c4b938
children ad9d2270860e
files lisp/ChangeLog lisp/emacs-lisp/lisp.el lisp/emacs-lisp/re-builder.el lisp/international/mule-cmds.el lisp/net/tramp.el
diffstat 5 files changed, 9 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Fri Jan 09 04:27:03 2009 +0000
+++ b/lisp/ChangeLog	Fri Jan 09 04:29:16 2009 +0000
@@ -7,7 +7,10 @@
 	* calc/calc-keypd.el, calc/calc-misc.el, calc/calc-prog.el:
 	* calc/calc-sel.el, calc/calc-store.el, calc/calc-stuff.el:
 	* calc/calc-units.el, calc/calc-yank.el, calc/calc.el:
+	* emacs-lisp/lisp.el, emacs-lisp/re-builder.el:
 	* eshell/em-smart.el, eshell/esh-mode.el:
+	* international/mule-cmds.el:
+	* net/tramp.el:
 	* play/mpuz.el:
 	* progmodes/ada-mode.el, progmodes/antlr-mode.el, progmodes/cc-align.el:
 	* progmodes/cc-cmds.el, progmodes/cperl-mode.el, progmodes/f90.el:
--- a/lisp/emacs-lisp/lisp.el	Fri Jan 09 04:27:03 2009 +0000
+++ b/lisp/emacs-lisp/lisp.el	Fri Jan 09 04:29:16 2009 +0000
@@ -474,7 +474,7 @@
 This command assumes point is not in a string or comment."
   (interactive "P")
   (if (not (and open close))
-      (let ((pair (or (assq last-command-char insert-pair-alist)
+      (let ((pair (or (assq last-command-event insert-pair-alist)
                       (assq (event-basic-type last-command-event)
                             insert-pair-alist))))
         (if pair
--- a/lisp/emacs-lisp/re-builder.el	Fri Jan 09 04:27:03 2009 +0000
+++ b/lisp/emacs-lisp/re-builder.el	Fri Jan 09 04:29:16 2009 +0000
@@ -564,7 +564,7 @@
   (interactive)
 
   (setq reb-subexp-displayed
-	(or subexp (string-to-number (format "%c" last-command-char))))
+	(or subexp (string-to-number (format "%c" last-command-event))))
   (reb-update-modestring)
   (reb-do-update reb-subexp-displayed))
 
--- a/lisp/net/tramp.el	Fri Jan 09 04:27:03 2009 +0000
+++ b/lisp/net/tramp.el	Fri Jan 09 04:29:16 2009 +0000
@@ -3738,10 +3738,10 @@
 	      ;; We don't need to handle `last-input-event', because
 	      ;; due to the key map we know it must be ?/ or ?~.
 	      (let ((s (concat (buffer-substring (point-min) (point))
-			       (string last-command-char))))
+			       (string last-command-event))))
 		(delete-region (point-min) (point))
 		(insert (substitute-in-file-name s))
-		(setq ad-return-value last-command-char))
+		(setq ad-return-value last-command-event))
 	    ad-do-it))))
 
    '(minibuffer-electric-separator
--- a/lisp/international/mule-cmds.el	Fri Jan 09 04:27:03 2009 +0000
+++ b/lisp/international/mule-cmds.el	Fri Jan 09 04:29:16 2009 +0000
@@ -299,10 +299,10 @@
 		     cmd (key-binding keyseq t))
 	       (not (eq cmd 'universal-argument-other-key)))
 	(let ((current-prefix-arg prefix-arg)
 	      ;; Have to bind `last-command-char' here so that
 	      ;; `digit-argument', for instance, can compute the
 	      ;; prefix arg.
-	      (last-command-char (aref keyseq 0)))
+	      (last-command-event (aref keyseq 0)))
 	  (call-interactively cmd)))
 
       ;; This is the final call to `universal-argument-other-key', which
@@ -299,10 +299,10 @@
 	       (not (eq cmd 'universal-argument-other-key)))
 	(let ((current-prefix-arg prefix-arg)
-	      ;; Have to bind `last-command-char' here so that
+	      ;; Have to bind `last-command-event' here so that
 	      ;; `digit-argument', for instance, can compute the
 	      ;; prefix arg.